@@ -1,2 +1,2 @@
-from PygameCase.Football import football, concise
+from PygameCase.Football import FootBall, concise
 from PygameCase.Football.show_code import show_code
